
**xlines** | Count the number of lines of text
------------------------------------------------

PACKAGE:  xlines


**xlines**:

    * Python3 commandline utility.
    * Essential software developer tools

**Features**:

    * Count lines in specific file objects provided as parameters
    * Alternatively provide a parent directory (project directory):

        * xlines sums all lines of text in all objects in subdirs.
        * outputs filename plus number of lines 

    * Exclusion list of File extensions not counted
    * User customizable
